/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 30/05/2025
 */

#include "vmp.h"

namespace vampiria { namespace vmp {

void *malloc_wrap(vmp_size size)
{
    void *ret=malloc(size);
    if(ret == 0)
       vmp::except_alloc();
    return ret;
}

void free_wrap(void **ptr)
{
    if((*ptr) != 0)
       free(*ptr);
    (*ptr)=0;
}

void bzero_wrap(void *s,vmp_size n)
{
    bzero(s,n);
}

void memcpy_wrap(void *dest, const void *src,vmp_size n)
{
    memcpy(dest,src,n);
}

vmp::str strerror_wrap(vmp_int err)
{
    return strerror(err);
}

void strncpy_wrap(vmp_char *dest, const vmp_char *src,vmp_size n)
{
    strncpy(dest,src,n);    
}

}}

